
### Description

A metaphor is a figure of speech in which one concept is used for another, and in which there is at least one point of comparison between the two. In other words, in metaphor, someone speaks of something as if it were something else because he wants people to understand that certain things that are true of one thing are true of the other. 

Sometimes a speaker does this in ways that are very common in the language. At other times, a speaker does this in ways that are less common in the language and that might even be unique. Speakers usually use metaphors in order to make their language more vivid or to give their language more emotional impact.

**Very Common ("Dead") Metaphors**

The metaphors that are very common in a language are usually not very vivid. They may even be "dead." A "dead" metaphor is a metaphor that has been used so much in the language that the speakers of the language do not think of it as a metaphor. Examples in English are "table leg," "family tree," and "the price of food is going up." Examples in biblical languages are "hand" to mean "power," "face" to mean "presence," and "clothing" to mean emotions or moral qualities. 

Metaphors like these are in constant use in the world's languages, because they serve as convenient ways to organize thought. In general, languages speak of abstract qualities, such as power, presence, emotions, and moral qualities, as if they were objects that can be seen or held, or as if they were body parts, or as if they were events that you can watch happen. 

When these metaphors are used in their normal ways, the speaker and audience of that language do not normally even regard them as figurative speech. It is just the normal way to say something in that language. This is why, for example, it would be wrong to translate the English expression, "The price of petrol is going up" into another language in a way that would draw special attention to it as figurative speech, because English speakers do not view it as a vivid expression. That is, it is not an unusual expression that carries meaning in an unusual manner. 

For a description of important patterns of this kind of metaphor, please see [Biblical Imagery - Common Patterns](../translate-bita-part1/01.md) and the pages it will direct you to. 

**Less Common ("Live") Metaphors** 

This is the kind of metaphor that we usually think of when we talk about metaphors. This is the kind that we need to take special care to translate accurately. These metaphors are vivid and have emotional impact because they make comparisons that are unusual and that are sometimes even unique in a language. 

The speaker usually produces metaphors of this kind in order to emphasize the importance of what he is talking about. For example, 

>For you who fear my name, the sun of righteousness will rise with healing in its wings. (Malachi 4:2 ULB)

Here God speaks about his salvation as if it were the sun rising to shine its rays on the people whom he loves. And he speaks of the sun's rays as if they were wings. Also, he speaks of these wings as if they were bringing medicine that would heal his people. 

We call this kind of metaphor "live." It is unique in the biblical languages, which means that it is very memorable. 

#### Parts of a Metaphor

When talking about metaphors, it can be helpful to talk about their parts. A metaphor has three parts. 

1. **Topic** The thing someone speaks of is called the topic. 
1. **Image** The thing he calls it is the image. 
1. **Points of Comparison** The ways that they are similar are the points of comparison. 

In the metaphor below, the speaker describes the woman he loves as a rose. The woman (his "love") is the **topic** and the red rose is the **image**. The **points of comparison** are that both the woman and the rose are beautiful and delicate. 

  * My love is a red, red rose. 

Normally, as in the metaphor above, the speaker explicitly states the **topic** and the **image**, but he does not state the **points of comparison**. The speaker leaves it to the hearer to think of the **points of comparison**. In that way, the speaker's message has more impact on the hearer.

Also in the Bible, normally the **topic** and the **image** are stated clearly, but not the **points of comparison**. 

>Jesus said to them. "**I am the bread of life**; he who comes to me will not be hungry, and he who believes in me will never be thirsty." (John 6:35 ULB)

In this metaphor, Jesus called himself the bread of life. The **topic** is "I" and the **image** is "bread." Bread is a food that people ate all the time. A **point of comparison** is that people need both to live. Just as people need to eat food in order to have physical life, people need to trust in Jesus in order to have spiritual life.

#### Purposes of this second kind of Metaphor

  * One purpose of metaphor is to teach people about something that they do not know (the **topic**) by showing that it is like something that they already do know (the **image**).
  * Another purpose  is to emphasize that something has a particular quality or to show that it has that quality in an extreme way.
  * Another purpose is to lead people to feel the same way about the one thing as they would feel about the other.

#### Reasons this is a translation issue

  * People may not recognize that something is a metaphor. In other words, they may mistake a metaphor for a literal statement, and thus misunderstand it.
  * People may not be familiar with the thing that is used as an image, and so not be able to understand the metaphor. 
  * If the topic is not stated, people may not know what the topic is.
  * People may not know the points of comparison, that is, they may not know how the topic and the image are alike, and so they will not understand the metaphor.

#### Translation Principles

  * Make the meaning of a metaphor as clear to the target audience as it was to the original audience.
  * Do not make the meaning of a metaphor more clear to the target audience than it was to the original audience.

### Examples from the Bible

>Listen to this word, <u>you cows of Bashan</u>, (Amos 4:1 ULB)

In this metaphor Amos compares the upper-class women of Samaria (the topic is "you") with cows (the image). The point of comparison is not stated, but from the context it seems that it is that both are fat and only interested in feeding themselves.

>And yet, Yahweh, you are our father; we are the <u>clay</u>. You are our <u>potter</u>; and we all are the work of your hand. (Isaiah 64:8 ULB)

The example above has two related metaphors. The topics are "we" and "you" and the images are "clay and "potter." The point of comparison is the relationship between the clay and the potter being similar to the relationship between us and God. Just as a potter takes clay and forms a jar or dish out of it, God makes us into what he wants us to be.

>Jesus said to them, "Take heed and beware of <u>the yeast of the Pharisees and Sadducees</u>." The disciples reasoned among themselves and said, "It is because we took no bread." (Matthew 16:6-7 ULB)

Jesus used a metaphor here, but his disciples did not realize it. When he said "yeast," they thought he was talking about bread, but "yeast" was the image in his metaphor, and the topic was the teaching of the Pharisees and Sadducees. Since the disciples (the original audience) did not understand what Jesus meant, it would not be good to state clearly here what Jesus meant.


### Translation Strategies

If people would understand the metaphor in the same way that the original readers would have understood it, go ahead and use it. Be sure to test the translation to make sure that people do understand it. If people do not or would not understand it, here are some other strategies.

1. If the metaphor is common and seems to be a normal way to say something in the source language (a "dead" metaphor), express the main idea in the simplest way preferred by your language. 
2. If the metaphor seems to be a "live" metaphor, you can translate it literally if you think that the target language also uses this metaphor. If you do this, be sure to test it to make sure that the language community understands it correctly. 
3. If the target audience does not understand the metaphor correctly, then change the metaphor to a simile. Some languages do this by adding words such as "like" or "as." See [Simile](../figs-simile/01.md)
4. If the target audience would not know the **image**, see [Translate Unknowns](../translate-unknown/01.md) for ideas on how to translate that image.
5. If the target audience would not use that **image** for that meaning, use an image from your own culture instead. Be sure that it is an image that could have been possible in Bible times. 
6. If the target audience would not know what the **topic** is, then state the topic clearly. (However, do not do this if the original audience did not know what the topic was.)
7. If the target audience would not know how the topic is like the image, then state a **point of comparison** clearly.
8. If none of these strategies are satisfactory, then just state the idea plainly without using a metaphor.


### Examples of Translation Strategies Applied

1. If the metaphor is common and seems to be a normal way to say something in the source language (a "dead" metaphor), express the main idea in the simplest way preferred by your language.
  * **And his brethren also went and <u>fell down before his face</u>;**  (Genesis 50:18 ASV)
     * Then his brothers also went and <u>immediately bowed down in front of him</u>;

2. If the metaphor seems to be a "live" metaphor, you can translate it literally if you think that the target language also uses this metaphor. If you do this, be sure to test it to make sure that the language community understands it correctly. 
  * **It was because of your <u>hard hearts</u> that he wrote you this law,**  (Mark 10:5 ULB)
     * It was because of your <u>hard hearts</u> that he wrote you this law, 
There is no change to this one - but it must be tested to make sure that the target audience correctly understands this metaphor.

3. If the target audience does not understand the metaphor correctly, then change the metaphor to a simile. Some languages do this by adding words such as "like" or "as."
  * **And yet, Yahweh, you are our father; we are the <u>clay</u>. You are our <u>potter</u>; and we all are the work of your hand.** (Isaiah 64:8 ULB)
     *  And yet, Yahweh, you are our father; we are <u>like</u> clay. You are <u>like</u> a potter; and we all are the work of your hand.
  
4. If the target audience would not know the **image**, see [Translate Unknowns](../translate-unknown/01.md) for ideas on how to translate that image.
  * **Saul, Saul, why do you persecute me? It is hard for you <u>to kick a goad</u>.** (Acts 26:14 ULB)
     * Saul, Saul, why do you persecute me? It is hard for you to <u>kick against a pointed stick</u>.

5. If the target audience would not use that **image** for that meaning, use an image from your own culture instead. Be sure that it is an image that could have been possible in Bible times. 
  * **And yet, Yahweh, you are our father; we are the <u>clay</u>. You are our <u>potter</u>; and we all are the work of your hand.** (Isaiah 64:8 ULB)
     * "And yet, Yahweh, you are our father; we are the <u>wood</u>. You are our <u>carver</u>; and we all are the work of your hand."
     * "And yet, Yahweh, you are our father; we are the <u>string</u>. You are the <u>weaver</u>; and we all are the work of your hand."

6. If the target audience would not know what the **topic** is, then state the topic clearly. (However, do not do this if the original audience did not know what the topic was.)
  * **Yahweh lives; may <u>my rock</u> be praised. May the God of my salvation be exalted.** (Psalm 18:46 ULB)
     * Yahweh lives; <u>He is my rock</u>. May he be praised. May the God of my salvation be exalted.

7. If the target audience would not know how the topic is like the image, then state a **point of comparison** clearly.
  * **Yahweh lives; may <u>my rock</u> be praised. May the God of my salvation be exalted.** (Psalm 18:46 ULB)
     * Yahweh lives; may he be praised because he is the rock <u>under which I can hide from my enemies</u>. May the God of my salvation be exalted.
 
  *  **Saul, Saul, why do you persecute me? It is hard for you <u>to kick a goad</u>.** (Acts 26:14 ULB)
     * Saul, Saul, why do you persecute me? You <u>fight against me and hurt yourself like an ox that kicks against its owner's pointed stick</u>. 

8. If none of these strategies are satisfactory, then just state the idea plainly without using a metaphor.
   * **I will make you become <u>fishers of men</u>.** (Mark 1:17 ULB)
     * I will make you become <u>people who gather men</u>.
     * Now you gather fish. I will make you <u>gather people</u>.

_To learn more about specific metaphors read:_

  * [Biblical Imagery - Common Patterns](../translate-bita-part1/01.md)